Security Advisories (1)
CPANSA-Jifty-2011-01 (2011-03-17)

The path as passed in the fragment request data structure was used verbatim in the dispatcher and other locations. This possibly allowed requests to walk around ACLs by requesting '/some/safe/place/../../../dangerous' as a fragment.

NAME

Jifty::Script::App - Create the skeleton of a Jifty application

SYNOPSIS

 jifty --name MyApp  Creates an application

Options:
  --name             application name

  --help             brief help message
  --man              full documentation

DESCRIPTION

This script creates the skeleton of your application. See Jifty::Manual::Tutorial for more information.

options

--name

Required option. It is the name of the application to create. Jifty will create a directory with that name, and place all of the files it creates inside that directory.

--help

Print a brief help message and exits.

--man

Prints the manual page and exits.

DESCRIPTION

Creates a skeleton of a new Jifty application. See Jifty::Manual::Tutorial for an example of its use.

METHODS

run

Create a directory for the application, a skeleton directory structure, and a Makefile.PL for you application.